@@ -107,6 +107,12 @@ struct des3_key {
 };
 #endif
 
+#ifdef LTC_SM4
+struct sm4_key {
+    ulong32 ek[32], dk[32];
+};
+#endif
+
 #ifdef LTC_CAST5
 struct cast5_key {
     ulong32 K[32], keylen;
@@ -184,6 +190,9 @@ typedef union Symmetric_key {
    struct desx_key desx;
    struct des3_key des3;
 #endif
+#ifdef LTC_SM4
+   struct sm4_key sm4;
+#endif
 #ifdef LTC_RC2
    struct rc2_key rc2;
 #endif
@@ -780,6 +789,16 @@ int des3_keysize(int *keysize);
 extern const struct ltc_cipher_descriptor des_desc, desx_desc, des3_desc;
 #endif
 
+#ifdef LTC_SM4
+int sm4_setup(const unsigned char *key, int keylen, int num_rounds, symmetric_key *skey);
+int sm4_ecb_encrypt(const unsigned char *pt, unsigned char *ct, const symmetric_key *skey);
+int sm4_ecb_decrypt(const unsigned char *ct, unsigned char *pt, const symmetric_key *skey);
+int sm4_test(void);
+void sm4_done(symmetric_key *skey);
+int sm4_keysize(int *keysize);
+extern const struct ltc_cipher_descriptor sm4_desc;
+#endif
+
 #ifdef LTC_CAST5
 int cast5_setup(const unsigned char *key, int keylen, int num_rounds, symmetric_key *skey);
 int cast5_ecb_encrypt(const unsigned char *pt, unsigned char *ct, const symmetric_key *skey);
